[kernel-options]
	config = cfg/crypto-obsolete-disable.scc
	config = cfg/sound.scc
	config = cfg/vmware-guest.scc
	config = cfg/fs/btrfs.scc
	config = cfg/fs/ext3.scc
	config = cfg/fs/flash_fs.scc
	config = cfg/fs/vfat.scc
	config = cfg/fs/devtmpfs.scc
	config = cfg/fs/debugfs.scc
	config = cfg/fs/ext2.scc
	config = cfg/fs/ext4.scc
	config = cfg/8250.scc
	config = cfg/usb-mass-storage.scc
	config = cfg/paravirt_kvm.scc
	config = cfg/debug-kselftest.scc
	config = cfg/hv-guest.scc
	config = cfg/smp.scc
	config = cfg/smp_64.scc
	config = cfg/vesafb.scc
	config = cfg/boot-live.scc
	config = cfg/efi.scc
	config = cfg/rbd.scc
	config = cfg/dmaengine.scc
	config = cfg/net/ip_nf.scc
	config = cfg/net/mdio.scc
	config = cfg/net/ipv6.scc
	config = cfg/net/ipsec.scc
	config = cfg/net/ip6_nf.scc
	config = cfg/net/bridge.scc
	config = cfg/net/ipsec6.scc
	config = cfg/virtio.scc
	config = cfg/debug/kcov/debug-kcov.scc
	config = cfg/debug/kcsan/debug-kcsan.scc
	config = cfg/debug/syzkaller/debug-syzkaller.scc
	config = cfg/debug/fault-inject/debug-fault-injection-debugfs.scc
	config = cfg/x32.scc
	config = cfg/timer/hpet.scc
	config = cfg/timer/hz_1000.scc
	config = cfg/timer/no_hz.scc
	config = cfg/timer/rtc.scc
	config = cfg/timer/hz_250.scc
	config = cfg/timer/hz_100.scc
	config = cfg/efi-ext.scc
	config = cgl/cfg/scsi_dh_hpsw.scc
	config = cgl/cfg/fs/ocfs2.scc
	config = cgl/cfg/drbd.scc
	config = cgl/cfg/scsi_dh_alua.scc
	config = cgl/cfg/scsi_dh_emc.scc
	config = cgl/cfg/scsi_dh_rdac.scc
	config = cgl/cfg/dmm.scc
	config = cgl/cfg/net/l2tp.scc
	config = cgl/cfg/net/macvlan.scc
	config = cgl/cfg/net/ip_vs.scc
	config = cgl/cfg/iscsi.scc
	config = cgl/cfg/scsi_dh.scc
	config = cgl/features/pstore/pstore.scc
	config = cgl/features/mip6/mip6.scc
	config = cgl/features/audit/audit.scc
	config = cgl/features/selinux/selinux-dev.scc
	config = cgl/features/selinux/selinux.scc
	config = cgl/features/aoe/aoe.scc
	config = cgl/features/quota/quota.scc
	config = features/pwm/pwm.scc
	config = features/pwm/intel_pwm.scc
	config = features/usb-net/usb-net.scc
	config = features/hrt/hrt.scc
	config = features/tmpfs/tmpfs-posix-acl.scc
	config = features/lxc/lxc-enable.scc
	config = features/intel-tco/intel-tco.scc
	config = features/ftrace/ftrace-function-tracer-disable.scc
	config = features/ftrace/ftrace.scc
	config = features/vxlan/vxlan-enable.scc
	config = features/i915/i915.scc
	config = features/nfc/nfc-generic.scc
	config = features/nfc/nfc-vendor.scc
	config = features/profiling/profiling.scc
	config = features/misc/bosch-pressure-sensor-i2c.scc
	config = features/security/security.scc
	config = features/kgdb/kgdb.scc
	config = features/vrf/vrf.scc
	config = features/usb/usb-gadgets.scc
	config = features/usb/serial-all.scc
	config = features/usb/designware-usb3.scc
	config = features/usb/usb-dummy-hcd.scc
	config = features/usb/touchscreen-composite.scc
	config = features/usb/uhci-hcd.scc
	config = features/usb/ehci-hcd.scc
	config = features/usb/designware-usb2.scc
	config = features/usb/usb-base.scc
	config = features/usb/ohci-hcd.scc
	config = features/usb/usb-typec.scc
	config = features/usb/serial.scc
	config = features/usb/xhci-hcd.scc
	config = features/usb/usb-raw-gadget.scc
	config = features/intel-uncore-frequency/intel-uncore-frequency.scc
	config = features/mpx/mpx.scc
	config = features/igb/igb.scc
	config = features/stm/stm.scc
	config = features/nf_tables/nf_tables.scc
	config = features/nf_tables/nft_test.scc
	config = features/cgroups/cgroups.scc
	config = features/can/m_can.scc
	config = features/can/can.scc
	config = features/intel-e1xxxx/intel-e100.scc
	config = features/mtd/mtd.scc
	config = features/blktrace/blktrace.scc
	config = features/landlock/landlock.scc
	config = features/iwlegacy/iwlegacy.scc
	config = features/kfence/kfence.scc
	config = features/latencytop/latencytop.scc
	config = features/bpf/bpf.scc
	config = features/xilinx/v4l2/v4l2.scc
	config = features/xilinx/overlay_of/overlay_of.scc
	config = features/xilinx/hdmi-module/hdmi-module.scc
	config = features/kmemcheck/kmemcheck-enable.scc
	config = features/uprobe/uprobe-enable.scc
	config = features/uprobe/uprobe.scc
	config = features/mmc/mmc-block.scc
	config = features/mmc/mmc-sdhci.scc
	config = features/mmc/mmc-base.scc
	config = features/mmc/mmc-realtek.scc
	config = features/scsi/scsi.scc
	config = features/scsi/scsi-debug.scc
	config = features/scsi/cdrom.scc
	config = features/scsi/disk.scc
	config = features/intel-idxd/intel-idxd.scc
	config = features/tun/tun.scc
	config = features/hid/hid.scc
	config = features/rpmb/rpmb-uapi.scc
	config = features/rpmb/rpmb-sim.scc
	config = features/rpmb/rpmb-base.scc
	config = features/igc/igc.scc
	config = features/iommu/iommu.scc
	config = features/systemtap/systemtap.scc
	config = features/intel-pmc/intel-pmc-core.scc
	config = features/tsn/tsn.scc
	config = features/power/bq25890.scc
	config = features/power/intel.scc
	config = features/power/intel_pmic.scc
	config = features/power/arm.scc
	config = features/bluetooth/bluetooth-usb.scc
	config = features/bluetooth/bluetooth-vhci.scc
	config = features/kexec/kexec-enable.scc
	config = features/serial/8250.scc
	config = features/intel-sst/intel-sst.scc
	config = features/intel-dptf/intel-dptf.scc
	config = features/wifi/wifi-all.scc
	config = features/wifi/wifi-usb.scc
	config = features/wifi/wifi-pci.scc
	config = features/wifi/wifi-sdio.scc
	config = features/wifi/wifi-common.scc
	config = features/gpio/mockup.scc
	config = features/gpio/sim.scc
	config = features/kprobes/kprobes.scc
	config = features/mfd/mfd-intel-lpss.scc
	config = features/thunderbolt/thunderbolt.scc
	config = features/intel-sgx/intel-sgx.scc
	config = features/transparent-hugepage/transparent-hugepage.scc
	config = features/netfilter/netfilter.scc
	config = features/mei/amt.scc
	config = features/mei/mei.scc
	config = features/mei/mei-txe.scc
	config = features/mei/mei-spd.scc
	config = features/mei/mei-me.scc
	config = features/kdump/kdump-enable.scc
	config = features/intel-persistent-memory/intel-x86-64-pmem.scc
	config = features/intel-persistent-memory/intel-x86-64-pmem-preempt-rt.scc
	config = features/ecryptfs/ecryptfs.scc
	config = features/module-signing/signing.scc
	config = features/module-signing/force-signing.scc
	config = features/docker/docker.scc
	config = features/reproducibility/reproducibility.scc
	config = features/leds/leds.scc
	config = features/apparmor/apparmor.scc
	config = features/yama/yama.scc
	config = features/criu/criu-enable.scc
	config = features/6lowpan/6lowpan.scc
	config = features/iio/iio.scc
	config = features/i40e/i40e.scc
	config = features/pci/pci-of-generic.scc
	config = features/pci/pci.scc
	config = features/i2c/i2c-ismt.scc
	config = features/i2c/i2cdev.scc
	config = features/i2c/i2c.scc
	config = features/i2c/i2cdbg.scc
	config = features/iscsi/iscsi.scc
	config = features/firewire/firewire.scc
	config = features/iwlwifi/iwlwifi.scc
	config = features/spi/spi.scc
	config = features/spi/spidev.scc
	config = features/kvm/qemu-kvm-enable.scc
	config = features/intel-th/intel-th.scc
	config = features/mac80211/mac80211-hwsim.scc
	config = features/mac80211/mac80211.scc
	config = features/qat/qat.scc
	config = features/device-mapper/dm-verity.scc
	config = features/ieee802154/ieee802154-hwsim.scc
	config = features/ima/ima.scc
	config = features/ima/modsign.scc
	config = features/fuse/fuse.scc
	config = features/xen/xen.scc
	config = features/powertop/powertop.scc
	config = features/full_nohz/full_nohz-enable.scc
	config = features/lto/lto.scc
	config = features/lto/lto-debug.scc
	config = features/lto/lto-disable.scc
	config = features/thermal/coretemp.scc
	config = features/ice/ice.scc
	config = features/ramconsole/ramconsole.scc
	config = features/eg20t/eg20t.scc
	config = features/edac/edac-enable.scc
	config = features/vfio/vfio.scc
	config = features/vswitch/vswitch.scc
	config = features/dca/dca.scc
	config = features/hugetlb/hugetlb.scc
	config = features/intel-txt/intel-txt.scc
	config = features/telemetry/intel-telemetry.scc
	config = features/i3c/i3c.scc
	config = features/intel-dpdk/intel-dpdk.scc
	config = features/ipmi/ipmi.scc
	config = features/intel-vmd/intel-vmd.scc
	config = features/debug/debug-runtime.scc
	config = features/debug/debug-kernel.scc
	config = features/debug/debug-dyndbg.scc
	config = features/debug/printk.scc
	config = features/debug/debug-btf.scc
	config = features/sound/snd_hda_intel.scc
	config = features/zram/zram.scc
	config = features/mgag200/mgag200.scc
	config = features/taskstats/taskstats.scc
	config = features/media/media-i2c.scc
	config = features/media/media.scc
	config = features/media/media-usb-tv.scc
	config = features/media/media-rc.scc
	config = features/media/media-usb-webcams.scc
	config = features/media/media-radio.scc
	config = features/media/media-platform.scc
	config = features/media/media-dvb-frontends.scc
	config = features/media/media-tuners.scc
	config = features/media/media-pci-capture.scc
	config = features/input/keyboard-gpio.scc
	config = features/input/input.scc
	config = features/input/touchscreen.scc
	config = features/nfsd/nfsd-enable.scc
	config = features/nfsd/nfsd.scc
	config = features/namespaces/namespaces.scc
	config = features/pci-iov/pci-iov.scc
	config = features/ocicontainer/xt-checksum.scc
	config = features/ocicontainer/ebtables.scc
	config = features/ocicontainer/cgroup.scc
	config = features/numa/numa.scc
	config = features/smack/smack.scc
	config = features/tpm/tpm-1.2.scc
	config = features/tpm/tpm-common.scc
	config = features/tpm/tpm-2.0-crb.scc
	config = features/tpm/tpm.scc
	config = features/tpm/tpm-2.0.scc
	config = features/tpm/vtpm.scc
	config = features/firmware/firmware.scc
	config = features/intel-pinctrl/intel-pinctrl.scc
	config = features/ciphers/ciphers.scc
	config = features/x2apic/x2apic.scc
	config = features/uio/uio.scc
	config = bsp/xilinx/board-common.scc
	config = bsp/xilinx/kc705-microblazeel-features/kc705-microblazeel-features.scc
	config = bsp/xilinx/soc/zynq.scc
	config = bsp/xilinx/soc/drivers-softip.scc
	config = bsp/xilinx/zybo-linux-bd-zynq7/zybo-linux-bd-zynq7.scc
	config = bsp/xilinx/ultra96-zynqmp/mipi-config-ultra96.scc
